@@ -10,6 +10,7 @@ from ipyleaflet import GeoJSON
 import geemap
 import ee
 
+from sepal_ui import color
 from sepal_ui.frontend.styles import AOI_STYLE
 from sepal_ui.scripts import utils as su
 from sepal_ui.scripts import gee
@@ -152,7 +153,7 @@ class AoiModel(Model):
     "geopandas.GeoDataFrame: the geodataframe corresponding to the selected AOI"
 
     feature_collection = None
-    "str: the name of the asset used to described the AOI"
+    "ee.FeatureCollection: The feature Collection generated by the parameters (only for GEE models)"
 
     ipygeojson = None
     "ipyleaflet.GeoJSON: the representation of the AOI as a ipyleaflet layer"
@@ -626,9 +627,12 @@ class AoiModel(Model):
         for f in data["features"]:
             f["properties"]["name"] = self.name
 
+        # adapt the style to the theme
+        style = {**AOI_STYLE, "color": color.success, "fillColor": color.success}
+
         # create a GeoJSON object
         self.ipygeojson = GeoJSON(
-            data=data, style=AOI_STYLE, name="aoi", attribution="SEPA(c)"
+            data=data, style=style, name="aoi", attribution="SEPAL(c)"
         )
 
         return self.ipygeojson
