@@ -9,6 +9,7 @@ if "PROJ_LIB" in list(os.environ.keys()):
 import collections
 from pathlib import Path
 from distutils.util import strtobool
+import warnings
 
 import geemap
 from haversine import haversine
@@ -27,13 +28,17 @@ from ipyleaflet import (
     ScaleControl,
     WidgetControl,
     ZoomControl,
+    GeoJSON,
 )
+from rasterio.crs import CRS
 from traitlets import Bool, link, observe
 import ipyvuetify as v
 import ipyleaflet
 import ee
 
+import sepal_ui.frontend.styles as styles
 from sepal_ui.scripts import utils as su
+from sepal_ui.scripts.warning import SepalWarning
 from sepal_ui.message import ms
 
 __all__ = ["SepalMap"]
@@ -55,7 +60,7 @@ class SepalMap(geemap.Map):
         basemaps ['str']: the basemaps used as background in the map. If multiple selection, they will be displayed as layers.
         dc (bool, optional): wether or not the drawing control should be displayed. default to false
         vinspector (bool, optional): Add value inspector to map, useful to inspect pixel values. default to false
-        ee (bool, optional): wether or not to use the ee binding. If False none of the earthengine display fonctionalities can be used. default to True
+        gee (bool, optional): wether or not to use the ee binding. If False none of the earthengine display fonctionalities can be used. default to True
         kwargs (optional): any parameter from a geemap.Map. if set, 'ee_initialize' will be overwritten.
     """
 
@@ -98,7 +103,10 @@ class SepalMap(geemap.Map):
         if len(basemaps):
             [self.add_basemap(basemap) for basemap in set(basemaps)]
         else:
-            self.add_basemap("CartoDB.DarkMatter")
+            default_basemap = (
+                "CartoDB.DarkMatter" if v.theme.dark is True else "CartoDB.Positron"
+            )
+            self.add_basemap(default_basemap)
 
         # add the base controls
         self.clear_controls()
@@ -400,6 +408,11 @@ class SepalMap(geemap.Map):
         # That will also improve performances as the generation of a tile can be done in parallel using Dask.
         da = da.chunk((1000, 1000))
 
+        # unproject if necessary
+        epsg_4326 = "EPSG:4326"
+        if da.rio.crs != CRS.from_string(epsg_4326):
+            da = da.rio.reproject(epsg_4326)
+
         # Create a named tuple with raster bounds and resolution
         local_raster = collections.namedtuple(
             "LocalRaster",
@@ -620,7 +633,7 @@ class SepalMap(geemap.Map):
             inverted = vis_params.pop("inverted", None)
             if inverted is not None:
 
-                # get the index of the bands taht need to be inverted
+                # get the index of the bands that need to be inverted
                 index_list = [i for i, v in enumerate(inverted) if v is True]
 
                 # multiply everything by -1
@@ -752,9 +765,41 @@ class SepalMap(geemap.Map):
             # set the value
             props[number][name] = val
 
-        # categorical values need to be cast to int
         for i in props.keys():
-            if props[i]["type"] == "categorical":
-                props[i]["values"] = [int(val) for val in props[i]["values"]]
+            if "type" in props[i]:
+                # categorical values need to be cast to int
+                if props[i]["type"] == "categorical":
+                    props[i]["values"] = [int(val) for val in props[i]["values"]]
+            else:
+                # if no "type" is provided guess it from the different parameters gathered
+                if len(props[i]["bands"]) == 1:
+                    props[i]["type"] = "continuous"
+                elif len(props[i]["bands"]) == 3:
+                    props[i]["type"] = "rgb"
+                else:
+                    warnings.warn(
+                        "the embed viz properties are incomplete or badly set, please review our documentation",
+                        SepalWarning,
+                    )
+                    props = {}
 
         return props
+
+    def add_layer(self, layer, hover=False):
+        """Add layer and use a default style for the GeoJSON inputs
+
+        hover (bool): whether to use the default hover style or not.
+
+        """
+
+        if isinstance(layer, GeoJSON):
+
+            if not layer.style:
+                layer.style = styles.layer_style
+
+            if hover and not layer.hover_style:
+                layer.hover_style = styles.layer_hover_style
+
+        super().add_layer(layer)
+
+        return self
