@@ -1,5 +1,5 @@
 # overwrite all the ipyvuetify widgets
-from sepal_ui.sepalwidgets.sepalwidget import SepalWidget, TYPES
+from sepal_ui.sepalwidgets.sepalwidget import SepalWidget
 import ipyvuetify as v
 
 
@@ -18,6 +18,9 @@ for c in _c_list:
     class _tmp(getattr(v, c), SepalWidget):
         pass
 
+    _tmp.__name__ = c
+    _tmp.__qualname__ = c
+
     locals()[c] = _tmp
 del _tmp
 
